@@ -1,4 +1,4 @@
-$(document).keydown(function(event) {
+$(document).keydown(function (event) {
   // focusing in text (area) inputs
 
   if (event.metaKey === false && event.ctrlKey === false && event.shiftKey === false) {
@@ -7,10 +7,14 @@ $(document).keydown(function(event) {
       $("#reg_store_res").click();
     } else if ($("#reg_store_pred_name").is(":focus") && event.keyCode == 13) {
       $("#reg_store_pred").click();
-    }else if ($("#logit_store_res_name").is(":focus") && event.keyCode == 13) {
+    } else if ($("#logit_store_res_name").is(":focus") && event.keyCode == 13) {
       $("#logit_store_res").click();
     } else if ($("#logit_store_pred_name").is(":focus") && event.keyCode == 13) {
       $("#logit_store_pred").click();
+    } else if ($("#mnl_store_res_name").is(":focus") && event.keyCode == 13) {
+      $("#mnl_store_res").click();
+    } else if ($("#mnl_store_pred_name").is(":focus") && event.keyCode == 13) {
+      $("#mnl_store_pred").click();
     } else if ($("#nb_store_pred_name").is(":focus") && event.keyCode == 13) {
       $("#nb_store_pred").click();
     } else if ($("#nn_store_res_name").is(":focus") && event.keyCode == 13) {
@@ -21,6 +25,14 @@ $(document).keydown(function(event) {
       $("#crtree_store_res").click();
     } else if ($("#crtree_store_pred_name").is(":focus") && event.keyCode == 13) {
       $("#crtree_store_pred").click();
+    } else if ($("#rf_store_res_name").is(":focus") && event.keyCode == 13) {
+      $("#rf_store_res").click();
+    } else if ($("#rf_store_pred_name").is(":focus") && event.keyCode == 13) {
+      $("#rf_store_pred").click();
+    } else if ($("#gbt_store_res_name").is(":focus") && event.keyCode == 13) {
+      $("#gbt_store_res").click();
+    } else if ($("#gbt_store_pred_name").is(":focus") && event.keyCode == 13) {
+      $("#gbt_store_pred").click();
     } else if ($("#crs_store_pred_name").is(":focus") && event.keyCode == 13) {
       $("#crs_store_pred").click();
     } else if ($("#sim_binom_p").is(":focus") && event.keyCode == 13) {
@@ -49,11 +61,11 @@ $(document).keydown(function(event) {
   }
 
   if ($("#dtree_load_yaml").is(":visible") && (event.metaKey || event.ctrlKey) &&
-      event.shiftKey === false && event.keyCode == 79) {
+    event.shiftKey === false && event.keyCode == 79) {
     $("#dtree_load_yaml").click();
     event.preventDefault();
   } else if ($("#dtree_save_yaml").is(":visible") && (event.metaKey || event.ctrlKey) &&
-     event.shiftKey === false && event.keyCode == 83) {
+    event.shiftKey === false && event.keyCode == 83) {
     $("#dtree_save_yaml").click();
     event.preventDefault();
   }
